//---------------------------------------------------------------------------
//
// Project:     SqliteClass
// Version:     0.3
// License:     Public Domain
//
// File:        SqliteConnection.h
// Author:      Gianni Rossi, Giuseppe Luciano
// Last Edit:   11/07/2011
//
//---------------------------------------------------------------------------

#ifndef SQLITECONNECTION_H
#define SQLITECONNECTION_H

#include "sqlite3.h"
#include "SqliteRecordSet.h"
#include "SqliteException.h"

#include <iostream>
using namespace std;

namespace SqliteClass {

   /** SqliteConnection open a SQLite3 file in order to execute query */
   class SqliteConnection
   {
      private:
         sqlite3* db;
         SqliteRecordSet* RecordSet;
         char* errMsg;

         void  execute(string Statement);
         bool TransStarted;

      public:
         /** Costructor */
         SqliteConnection();
         ~SqliteConnection();

         /** Begin a transaction
           * @exception SqliteException may throws
           */
         bool begin();

         /** Commit a transaction
           * commit works if begin() is called before
           * @exception SqliteException may throws
          */
         bool commit();

         /** Restore the database
           * roolback works if begin() is called before
           * @exception SqliteException may throws
           */
         bool rollback();

         /** Open a SQLite3 file
           * If the database file does not exist, it will be create
           * @param DBFile File SQLite3 to open
           */
         bool open(string DBFile);

         /** Close a connection to a SQLite3 file*/
         int close();

         /** Execute an SQL Update statemant
           * @param Statement SQL Statement to execute
           * @exception SqliteException if Statement isn't SQL valid
           */
         void executeUpdate(string Statement);

         /** Execute an SQL Query,
           * @param Statement SQL Statement to execute
           * @param RecordsAffected is an instance of SqliteRecordSet
           * @exception SqliteException if Statement isn't SQL valid
           */
         void executeQuery(string Statement, SqliteRecordSet*& RecordsAffected);

         /** Get the last error */
         const char* getLastError();

         void loadResult(int argc, char **argv, char **azColName);

   };

}
#endif
