//---------------------------------------------------------------------------
//
// Project:     SqliteClass
// Version:     0.3
// License:     Public Domain
//
// File:        SqliteRecordSet.h
// Author:      Gianni Rossi, Giuseppe Luciano
// Last Edit:   11/07/2011
//
//---------------------------------------------------------------------------

#ifndef SQLITERECORDSET_H
#define SQLITERECORDSET_H

#include "SqliteException.h"
#include <vector>
#include <string>
using namespace std;

namespace SqliteClass {

   /** SqliteRecordSet contains the result of an SQL Query */
   class SqliteRecordSet
   {
      private:
         vector< string > Columns;
         vector< vector<string> > DataSet;
         int CurrentRowIndex;
         int IndexOfColumn(string Field);

      public:
         /** Costructor */
         SqliteRecordSet();
         ~SqliteRecordSet();

         void AddColumn(string Name);
         void NewRow();
         void addDataRow(int argc, char **argv);

         /** Return the number of columns*/
         unsigned int columns();
         /** Return the number of rows*/
         unsigned int rows();

         /** Check if RecordSet is empty*/
         bool isEmpty();
         /** Check if the cursor is on last row*/
         bool isLast();
         /** Check if the cursor is on first row*/
         bool isFirst();

         /** Move to first row*/
         bool first();
         /** Move to last row*/
         bool last();
         /** Move to next row*/
         bool next();
         /** Move to previus row*/
         bool prev();
         /** Move to a row*/
         bool moveTo(unsigned int row);

         /** Get the value of the row by column name*/
         string fieldValue(string columName);
         /** Get the value of the row by column index */
         string fieldValue(int fieldIndex);

         /** Get the column name by index */
         string getColumnName(int columnIndex);
   };

}
#endif
